@@ -27,6 +27,7 @@
 #include "sol.h"
 #include "slot.h"
 #include "menu.h"
+#include "draw.h"
 
 lambda_data* game_data = NULL;
 
@@ -38,8 +39,8 @@ void add_slot(SCM slot_data)
 
   hslot->id = SCM_INUM(SCM_CAR(slot_data));
   hslot->cards = new_deck(SCM_CADR(slot_data));
-  hslot->x = SCM_INUM(SCM_CAR(SCM_CADR(SCM_CADDR(slot_data))));
-  hslot->y = SCM_INUM(SCM_CADR(SCM_CADR(SCM_CADDR(slot_data))));
+  hslot->x = gh_scm2double (SCM_CAR(SCM_CADR(SCM_CADDR(slot_data))));
+  hslot->y = gh_scm2double (SCM_CADR(SCM_CADR(SCM_CADDR(slot_data))));
   
   hslot->dx = hslot->dy = 0;
   hslot->expansion_depth = 0;
@@ -54,7 +55,7 @@ void add_slot(SCM slot_data)
   else if (!strcmp("partially-expanded", 
 		   SCM_CHARS(SCM_CAR(SCM_CADDR(slot_data))))) {
     hslot->dy = y_expanded_offset;
-    hslot->expansion_depth = SCM_INUM(SCM_CADDR(SCM_CADDR(slot_data)));
+    hslot->expansion_depth = SCM_INUM (SCM_CADDR(SCM_CADDR(slot_data)));
   }
   else if (!strcmp("partially-expanded-right", 
 		   SCM_CHARS(SCM_CAR(SCM_CADDR(slot_data))))) {
@@ -110,7 +111,7 @@ static SCM scm_gettext(SCM message)
 {
   static char * input = NULL;
   char * output;
-  int len;
+  size_t len;
 
   /* This is needed because we can't free the string before returning
    * if it isn't translated. This way we have a permanent one-string
@@ -143,36 +144,6 @@ static SCM scm_redo_set_sensitive (SCM in_state)
   return SCM_EOL;
 }
 
-static SCM scm_get_card_width() 
-{
-  return gh_long2scm(get_card_width());
-}
-
-static SCM scm_get_card_height() 
-{
-  return gh_long2scm(get_card_height());
-}
-
-static SCM scm_get_horiz_offset() 
-{
-  return gh_long2scm(get_horiz_offset());
-}
-
-static SCM scm_get_vert_offset() 
-{
-  return gh_long2scm(get_vert_offset());
-}
-
-static SCM scm_get_horiz_start() 
-{
-  return gh_long2scm(get_horiz_start());
-}
-
-static SCM scm_get_vert_start() 
-{
-  return gh_long2scm(get_vert_start());
-}
-
 static SCM scm_set_statusbar_message(SCM message)
 {
   gnome_appbar_clear_stack (GNOME_APPBAR (GNOME_APP (app)->statusbar));
@@ -209,14 +180,14 @@ static SCM gg_scm_add_slot(SCM slot)
 static SCM scm_set_slot_y_expansion(SCM scm_slot_id, SCM new_exp_val)
 {
   hslot_type slot = get_slot(gh_scm2int(scm_slot_id));
-  slot->dy = gh_scm2int(new_exp_val);
+  slot->dy = gh_scm2double (new_exp_val);
   return SCM_EOL;
 }
 
 static SCM scm_set_slot_x_expansion(SCM scm_slot_id, SCM new_exp_val)
 {
   hslot_type slot = get_slot(gh_scm2int(scm_slot_id));
-  slot->dx = gh_scm2int(new_exp_val);
+  slot->dx = gh_scm2double (new_exp_val);
   return SCM_EOL;
 }
 
@@ -317,12 +288,6 @@ void cscm_init ()
      and it looked as good a test as any  */
   gh_eval_str ("(if (not (defined? \'provide))\n"
   	       "  (primitive-load-path \"ice-9/boot-9.scm\"))");
-  gh_new_procedure0_0("get-card-width", scm_get_card_width);
-  gh_new_procedure0_0("get-card-height", scm_get_card_height);
-  gh_new_procedure0_0("get-horiz-offset",scm_get_horiz_offset);
-  gh_new_procedure0_0("get-vert-offset", scm_get_vert_offset);
-  gh_new_procedure0_0("get-horiz-start", scm_get_horiz_start);
-  gh_new_procedure0_0("get-vert-start", scm_get_vert_start);
   gh_new_procedure1_0("set-statusbar-message", scm_set_statusbar_message);
   gh_new_procedure1_0("set-surface-layout", scm_set_surface_layout);
   gh_new_procedure0_0("reset-surface", scm_reset_surface);
